@@ -40,14 +40,16 @@ is_intercept <- function(intercept) {
 check_inputs_root_node <- function(name, type) {
 
   if (!is_node_name(name)) {
-    stop("The 'name' attribute must be character vector of length >= 1.")
+    stop("The 'name' attribute must be character vector of length >= 1.",
+         call.=FALSE)
   } else if (!is_node_dist(type)) {
     stop("The 'type' parameter of a root node must be a single",
-         " character string naming a defined function.")
+         " character string naming a defined function.", call.=FALSE)
   } else if (!is.function(type) && type %in% c("identity", "node_identity")) {
     stop("Nodes of type 'identity' cannot be used as root nodes, e.g. at",
          " least one variable name has to be\nmentioned in 'formula'. Use",
-         " type='rconstant' instead to specify a constant value.")
+         " type='rconstant' instead to specify a constant value.",
+         call.=FALSE)
   }
 }
 
@@ -56,16 +58,19 @@ check_inputs_child_node <- function(name, type, parents, args, time_varying,
                                     formula) {
 
   if (!is_node_name(name)) {
-    stop("The 'name' attribute must be character vector of length >= 1.")
+    stop("The 'name' attribute must be character vector of length >= 1.",
+         call.=FALSE)
   } else if (!is_node_type(type)) {
     stop("The 'type' parameter of a child node must be a single",
-         " character string pointing to a function starting with 'node_'.")
+         " character string pointing to a function starting with 'node_'.",
+         call.=FALSE)
   } else if (!is_node_parents(parents) & !time_varying) {
     stop("The 'parents' argument of a child node must be a character",
-         " vector of length > 0.")
+         " vector of length > 0.", call.=FALSE)
   } else if (!(is_formula(formula) | is.null(formula) |
                is.character(formula))) {
-    stop("'formula' must be a valid formula object, a special formula or NULL.")
+    stop("'formula' must be a valid formula object, a special formula or NULL.",
+         call.=FALSE)
   }
 
   # type specific checks
@@ -89,18 +94,22 @@ check_inputs_child_node <- function(name, type, parents, args, time_varying,
 check_inputs_node_regression <- function(parents, args, type) {
 
   if (is.null(args$betas) & !is.character(args$formula)) {
-    stop("'betas' must be defined when using type='", type, "'.")
+    stop("'betas' must be defined when using type='", type, "'.",
+         call.=FALSE)
   } else if (is.null(args$intercept) & !is.character(args$formula)) {
-    stop("'intercept' must be defined when using type='", type, "'.")
+    stop("'intercept' must be defined when using type='", type, "'.",
+         call.=FALSE)
   }
 
   if (!is_betas(args$betas) & !is.character(args$formula)) {
-    stop("'betas' must be a numeric vector when using type='", type, "'.")
+    stop("'betas' must be a numeric vector when using type='", type, "'.",
+         call.=FALSE)
   } else if (!is_intercept(args$intercept) & !is.character(args$formula)) {
-    stop("'intercept' must be a single number when using type='", type, "'.")
+    stop("'intercept' must be a single number when using type='", type, "'.",
+         call.=FALSE)
   } else if ((length(parents) != length(args$betas)) & is.null(args$formula)) {
     stop("'betas' must have the same length as 'parents' when using",
-         " type='", type, "'.")
+         " type='", type, "'.", call.=FALSE)
   }
 }
 
@@ -110,7 +119,7 @@ check_inputs_node_gaussian <- function(parents, args) {
   check_inputs_node_regression(parents=parents, args=args, type="gaussian")
 
   if (is.null(args$error)) {
-    stop("'error' must be defined when using type='gaussian'.")
+    stop("'error' must be defined when using type='gaussian'.", call.=FALSE)
   }
 }
 
@@ -135,16 +144,16 @@ check_inputs_sim_from_dag <- function(dag, n_sim, sort_dag) {
 
   # rudimentary type checks
   if (!(length(n_sim)==1 && is.numeric(n_sim) && n_sim > 0)) {
-    stop("'n_sim' must be a single integer > 0.")
+    stop("'n_sim' must be a single integer > 0.", call.=FALSE)
   } else if (!(length(sort_dag)==1 && is.logical(sort_dag))) {
-    stop("'sort_dag' must be either TRUE or FALSE.")
+    stop("'sort_dag' must be either TRUE or FALSE.", call.=FALSE)
   } else if (!inherits(dag, "DAG")) {
     stop("'dag' must be a DAG object creates using empty_dag() and",
-         " node() function calls. See documentation.")
+         " node() function calls. See documentation.", call.=FALSE)
   } else if (is_time_varying_dag(dag)) {
     stop("'The 'dag' object may not contain time-varying nodes. Use",
          " the 'sim_discrete_time' function instead or remove all",
-         " time-varying nodes.")
+         " time-varying nodes.", call.=FALSE)
   }
 }
 
@@ -155,15 +164,16 @@ check_inputs_node_conditional_probs <- function(data, parents, probs,
   dep_probs_length <- unlist(lapply(probs, length))
   if (min(dep_probs_length, na.rm=TRUE) != max(dep_probs_length, na.rm=TRUE)) {
     stop("There must be an equal number of probabilities for each",
-         " possible value in 'probs'.")
+         " possible value in 'probs'.", call.=FALSE)
   } else if (is.null(names(probs))) {
-    stop("All elements in 'probs' must be named using levels of 'parents'.")
+    stop("All elements in 'probs' must be named using levels of 'parents'.",
+         call.=FALSE)
   } else if (length(parents) == 1 &&
              !all(names(probs) %in% unique(data[[parents]]))) {
     stop("All elements in 'probs' must correspond to levels in ", parents,
          ". The following elements are not: ",
          paste0(names(probs)[!names(probs) %in% unique(data[[parents]])],
-                collapse="  "))
+                collapse="  "), call.=FALSE)
   } else if (length(parents) > 1 &&
              !all(names(probs) %in%
                   unique(interaction(data[, parents, with=FALSE])))) {
@@ -171,17 +181,17 @@ check_inputs_node_conditional_probs <- function(data, parents, probs,
          "combined strata of all 'parents'. The following elements are not: ",
          paste0(names(probs)[!names(probs) %in%
                       unique(interaction(data[, parents, with=FALSE]))],
-                collaps="  "))
+                collaps="  "), call.=FALSE)
   } else if (!(is.null(default_probs) || (is.numeric(default_probs) &&
                all(default_probs <=1 & default_probs >= 0)))) {
     stop("'default_probs' must be a numeric vector containing only",
-         " values between 0 and 1 or NULL.")
+         " values between 0 and 1 or NULL.", call.=FALSE)
   } else if (!is.null(default_probs) &
              length(default_probs) != min(dep_probs_length, na.rm=TRUE)) {
     stop("'default_probs' should contain one entry for each possible",
-         " output class.")
+         " output class.", call.=FALSE)
   } else if (length(default_val) != 1) {
-    stop("'default_val' must be a vector of length 1.")
+    stop("'default_val' must be a vector of length 1.", call.=FALSE)
   }
 }
 
@@ -192,13 +202,14 @@ check_inputs_node_conditional_distr <- function(data, parents, distr,
                                                 coerce2numeric) {
 
   if (is.null(names(distr))) {
-    stop("All elements in 'distr' must be named using levels of 'parents'.")
+    stop("All elements in 'distr' must be named using levels of 'parents'.",
+         call.=FALSE)
   } else if (length(parents) == 1 &&
              !all(names(distr) %in% unique(data[[parents]]))) {
     stop("All elements in 'distr' must correspond to levels in ", parents,
          ". The following elements are not: ",
          paste0(names(distr)[!names(distr) %in% unique(data[[parents]])],
-                collapse="  "))
+                collapse="  "), call.=FALSE)
   } else if (length(parents) > 1 &&
              !all(names(distr) %in%
                   unique(interaction(data[, parents, with=FALSE])))) {
@@ -206,13 +217,13 @@ check_inputs_node_conditional_distr <- function(data, parents, distr,
          "combined strata of all 'parents'. The following elements are not: ",
          paste0(names(distr)[!names(distr) %in%
                         unique(interaction(data[, parents, with=FALSE]))],
-                collapse="  "))
+                collapse="  "), call.=FALSE)
   } else if (!is.function(default_distr) && !is.null(default_distr)) {
-    stop("'default_distr' must be a function or NULL.")
+    stop("'default_distr' must be a function or NULL.", call.=FALSE)
   } else if (length(default_val) != 1) {
     stop("'default_val' must be of length 1.")
   } else if (!(is.logical(coerce2numeric) && length(coerce2numeric)==1)) {
-    stop("'coerce2numeric' must be either TRUE or FALSE.")
+    stop("'coerce2numeric' must be either TRUE or FALSE.", call.=FALSE)
   }
 }
 
@@ -220,28 +231,30 @@ check_inputs_node_conditional_distr <- function(data, parents, distr,
 check_inputs_long2start_stop <- function(data, id, time, varying) {
 
   if (nrow(data)==0) {
-    stop("'data' needs to have at least 1 row.")
+    stop("'data' needs to have at least 1 row.", call.=FALSE)
   } else if (!(is.character(id) && length(id)==1)) {
     stop("'id' has to be a single character string, specifying the unique",
-         " person identifier in 'data'.")
+         " person identifier in 'data'.", call.=FALSE)
   } else if (!id %in% colnames(data)) {
-    stop(id, " is not a valid column in 'data'.")
+    stop(id, " is not a valid column in 'data'.", call.=FALSE)
   } else if (!(is.character(data[[id]]) | is.numeric(data[[id]]))) {
     stop("The column specified by 'id' must be a character, factor or",
-         " integer variable.")
+         " integer variable.", call.=FALSE)
   } else if (!(is.character(time) && length(time)==1)) {
     stop("'time' has to be a single character string, specifying the",
-         " variable containing points in time in 'data'.")
+         " variable containing points in time in 'data'.", call.=FALSE)
   } else if (!time %in% colnames(data)) {
-    stop(time, " is not a valid column in 'data'.")
+    stop(time, " is not a valid column in 'data'.", call.=FALSE)
   } else if (!all(data[[time]] %% 1==0)) {
-    stop("The variable specified by 'time' may only contain integers.")
+    stop("The variable specified by 'time' may only contain integers.",
+         call.=FALSE)
   } else if (!((is.null(varying) | is.character(varying)))) {
     stop("'varying' must be a character vector specifying variables that",
-         " change over time in 'data'.")
+         " change over time in 'data'.", call.=FALSE)
   } else if (!all(varying %in% colnames(data))) {
     stop("The following names in 'varying' are not contained in 'data': ",
-         paste0(varying[!varying %in% colnames(data)], collapse=", "))
+         paste0(varying[!varying %in% colnames(data)], collapse=", "),
+         call.=FALSE)
   }
 
   if (length(varying)==0) {
@@ -252,28 +265,33 @@ check_inputs_long2start_stop <- function(data, id, time, varying) {
 ## check user inputs to sim2data function
 check_inputs_sim2data <- function(sim, use_saved_states, to, target_event,
                                   keep_only_first, overlap,
-                                  remove_not_at_risk) {
+                                  remove_not_at_risk, remove_vars) {
 
   # errors
   if (!inherits(sim, "simDT")) {
     stop("'sim' needs to be a simDT object created using the",
-         " sim_discrete_time() function.")
+         " sim_discrete_time() function.", call.=FALSE)
   } else if (!(is.logical(use_saved_states) & length(use_saved_states)==1)) {
-    stop("'use_saved_states' must be either TRUE or FALSE.")
+    stop("'use_saved_states' must be either TRUE or FALSE.", call.=FALSE)
   } else if (use_saved_states & sim$save_states=="last") {
     stop("use_saved_states=TRUE cannot be used if save_states='last'",
          " was used in the original sim_discrete_time() function call.",
-         " Set to FALSE or rerun simulation.")
+         " Set to FALSE or rerun simulation.", call.=FALSE)
   } else if (!(is.character(to) & length(to)==1 &
                to %in% c("start_stop", "long", "wide"))) {
-    stop("'to' must be one of: 'start_stop', 'long', 'wide'.")
+    stop("'to' must be one of: 'start_stop', 'long', 'wide'.", call.=FALSE)
   } else if (!(is.logical(keep_only_first) & length(keep_only_first)==1)) {
-    stop("'keep_only_first' must be either TRUE or FALSE.")
+    stop("'keep_only_first' must be either TRUE or FALSE.", call.=FALSE)
   } else if (!(is.logical(overlap) & length(overlap)==1)) {
-    stop("'overlap' must be either TRUE or FALSE.")
+    stop("'overlap' must be either TRUE or FALSE.", call.=FALSE)
   } else if (!(is.logical(remove_not_at_risk) &
                length(remove_not_at_risk)==1)) {
-    stop("'remove_not_at_risk' must be either TRUE or FALSE.")
+    stop("'remove_not_at_risk' must be either TRUE or FALSE.", call.=FALSE)
+  } else if (!(is.null(remove_vars) ||
+               (length(remove_vars) > 0 && is.character(remove_vars)))) {
+    stop("'remove_vars' must be either NULL or a character vector, ",
+         "specifying which variables should not be included in the output.",
+         call.=FALSE)
   }
 
   # extract node_time_to_event objects
@@ -286,7 +304,14 @@ check_inputs_sim2data <- function(sim, use_saved_states, to, target_event,
                                   length(target_event)==1 &&
                                   target_event %in% tte_names)) {
     stop("'target_event' must be a single character string, specifying a",
-         " time_to_event node used in the creation of 'sim'.")
+         " time_to_event node used in the creation of 'sim'.", call.=FALSE)
+  }
+
+  if (any(tte_names %in% c(".id", "start", "stop"))) {
+    stop("Cannot transform the data because one of the protected",
+         " column names '.id', 'start' or 'stop' was used as a node name.",
+         " \nPlease rename these nodes and re-run the simulation.",
+         call.=FALSE)
   }
 
   # raise warning due to missing information if needed
@@ -322,7 +347,7 @@ check_inputs_plot.simDT <- function(right_boxes, box_hdist, box_vdist,
 
   # logical values
   if (!(is.logical(right_boxes) && length(right_boxes)==1)) {
-    stop("'right_boxes' must be either TRUE or FALSE.")
+    stop("'right_boxes' must be either TRUE or FALSE.", call.=FALSE)
   }
 
   # numeric values
@@ -333,7 +358,7 @@ check_inputs_plot.simDT <- function(right_boxes, box_hdist, box_vdist,
   for (i in seq_len(length(number_checks))) {
     arg <- number_checks[[i]]
     if (!(is.numeric(arg) && length(arg==1))) {
-      stop("'", check_names[[i]], "' must be a single number.")
+      stop("'", check_names[[i]], "' must be a single number.", call.=FALSE)
     }
   }
 
@@ -343,14 +368,16 @@ check_inputs_plot.simDT <- function(right_boxes, box_hdist, box_vdist,
   for (i in seq_len(length(str_checks))) {
     arg <- str_checks[[i]]
     if (!(is.character(arg) && length(arg==1))) {
-      stop("'", check_names[[i]], "' must be a single character string.")
+      stop("'", check_names[[i]], "' must be a single character string.",
+           call.=FALSE)
     }
   }
 
   # is separate here because it allows NULL
   if (!(is.character(box_1_text_right) && length(box_1_text_right)==1) &&
       !is.null(box_1_text_right)) {
-    stop("'box_1_text_right' must be a single character string or NULL.")
+    stop("'box_1_text_right' must be a single character string or NULL.",
+         call.=FALSE)
   }
 
   # multiple character values
@@ -358,12 +385,13 @@ check_inputs_plot.simDT <- function(right_boxes, box_hdist, box_vdist,
         length(box_l_node_labels)==length(tx_names)) &&
       !is.null(box_l_node_labels)) {
     stop("'box_l_node_labels' must be a character vector with one entry for",
-         " each tx_node in the original sim_discrete_time() call.")
+         " each tx_node in the original sim_discrete_time() call.",
+         call.=FALSE)
   } else if (!(is.character(box_r_node_labels) &&
                length(box_r_node_labels)==length(tx_names)) &&
              !is.null(box_r_node_labels)) {
     stop("'box_r_node_labels' must be a character vector with one entry for",
-         " each tx_node in the original sim_discrete_time() call.")
+         " each tx_node in the original sim_discrete_time() call.", call.=FALSE)
   }
 }
 
@@ -372,11 +400,12 @@ check_inputs_do <- function(dag, names, values) {
 
   if (!inherits(dag, "DAG")) {
     stop("'dag' must be a DAG object created using the empty_dag() and node()",
-         " functions. See ?node for a description on how to do this.")
+         " functions. See ?node for a description on how to do this.",
+         call.=FALSE)
   } else if (!(is.character(names) & length(names) > 0)) {
-    stop("'names' must be a character vector of length > 0.")
+    stop("'names' must be a character vector of length > 0.", call.=FALSE)
   } else if (length(names) != length(values)) {
-    stop("'names' must have the same length as 'values'.")
+    stop("'names' must have the same length as 'values'.", call.=FALSE)
   }
 }
 
@@ -385,16 +414,16 @@ check_inputs_dag_from_data <- function(dag, data, return_models, na.rm) {
 
   if (!inherits(dag, "DAG")) {
     stop("'dag' must be a DAG object created using the empty_dag() and",
-         " node() function calls. See ?node for more details.")
+         " node() function calls. See ?node for more details.", call.=FALSE)
   } else if (!inherits(data, "data.frame")) {
-    stop("'data' must be a data.frame or data.table.")
+    stop("'data' must be a data.frame or data.table.", call.=FALSE)
   } else if (!(is.logical(return_models) & length(return_models)==1)) {
-    stop("'return_models' must be either TRUE or FALSE.")
+    stop("'return_models' must be either TRUE or FALSE.", call.=FALSE)
   } else if (!(is.logical(na.rm) & length(na.rm)==1)) {
-    stop("'na.rm' must be either TRUE or FALSE.")
+    stop("'na.rm' must be either TRUE or FALSE.", call.=FALSE)
   } else if (is_time_varying_dag(dag)) {
     stop("'dag' may not contain time-dependent nodes added with the",
-         " node_td() function.")
+         " node_td() function.", call.=FALSE)
   }
 
   # check if all nodes are in data
@@ -402,7 +431,8 @@ check_inputs_dag_from_data <- function(dag, data, return_models, na.rm) {
                  lapply(dag$child_nodes, function(x){x$name}))
   if (!all(dag_names %in% colnames(data))) {
     stop("All nodes in 'dag' must correspond to a column in 'data'.",
-         "Missing columns: ", dag_names[!dag_names %in% colnames(data)])
+         "Missing columns: ", dag_names[!dag_names %in% colnames(data)],
+         call.=FALSE)
   }
 }
 
@@ -412,26 +442,26 @@ check_inputs_plot.DAG <- function(dag, node_size, node_names, arrow_node_dist,
 
   if (!inherits(dag, "DAG")) {
     stop("'x' must be a DAG object created using the empty_dag() and node()",
-         " functions.")
+         " functions.", call.=FALSE)
   }
 
   size_dag <- length(names_DAG(dag, include_tx_nodes=include_td_nodes))
 
   if (size_dag < 2) {
-    stop("The supplied DAG must have at least two nodes.")
+    stop("The supplied DAG must have at least two nodes.", call.=FALSE)
   } else if (!((length(node_names) == size_dag && is.character(node_names)) |
                is.null(node_names))) {
     stop("'node_names' must be a character vector with one name for each node",
-         " or NULL.")
+         " or NULL.", call.=FALSE)
   } else if (!((length(node_size) == 1 | length(node_size) == size_dag) &&
                 is.numeric(node_size) && all(node_size > 0))) {
     stop("'node_size' must be a numeric vector of length 1 or with one entry",
-         " per node. May only contain positive numbers.")
+         " per node. May only contain positive numbers.", call.=FALSE)
   } else if (!(length(arrow_node_dist)==1 && is.numeric(arrow_node_dist) &&
                arrow_node_dist >= 0)) {
-    stop("'arrow_node_dist' must a single number >= 0.")
+    stop("'arrow_node_dist' must a single number >= 0.", call.=FALSE)
   } else if (!ggplot2::is.theme(gg_theme)) {
-    stop("'gg_theme' must be a ggplot2 theme object.")
+    stop("'gg_theme' must be a ggplot2 theme object.", call.=FALSE)
   }
 }
 
@@ -447,7 +477,8 @@ check_inputs_sim_discrete_time <- function(n_sim, dag, t0_sort_dag,
   if (!is_time_varying_dag(dag)) {
     stop("'dag' must contain at least one time-varying node added using",
          " the node_td() function. For dag objects with no time-varying",
-         " nodes, please use the sim_from_dag() function instead.")
+         " nodes, please use the sim_from_dag() function instead.",
+         call.=FALSE)
   }
   if (!is.null(t0_data)) {
     stopifnot("'t0_data' must be a data.frame." = is.data.frame(t0_data))
@@ -475,7 +506,7 @@ check_inputs_sim_discrete_time <- function(n_sim, dag, t0_sort_dag,
   if (!is.null(save_states_at)) {
     if (!is.numeric(save_states_at))  {
       stop("'save_states_at' must be either a single integer",
-           " or a vector of type numeric.")
+           " or a vector of type numeric.", call.=FALSE)
     }
   }
   stopifnot("'verbose' must be logical." = is.logical(verbose))
@@ -500,7 +531,8 @@ check_inputs_sim_discrete_time <- function(n_sim, dag, t0_sort_dag,
     if (!all(names_args %in% names_fun)) {
       stop("The following arguments are in 't0_transform_args' but are",
            " not define in 't0_transform_fun': ",
-           paste0(names_args[!names_args %in% names_fun], collapse=","))
+           paste0(names_args[!names_args %in% names_fun], collapse=","),
+           call.=FALSE)
     }
   }
 
@@ -508,7 +540,7 @@ check_inputs_sim_discrete_time <- function(n_sim, dag, t0_sort_dag,
   if (is.vector(tx_nodes_order)) {
     if (!identical(length(tx_nodes_order), length(tx_nodes))) {
       stop("'tx_nodes_order' must be the same length as",
-           " the number of time-varying nodes in the dag.")
+           " the number of time-varying nodes in the dag.", call.=FALSE)
     }
   }
 
@@ -524,7 +556,8 @@ check_inputs_sim_discrete_time <- function(n_sim, dag, t0_sort_dag,
     if (!all(names_args %in% names_fun)) {
       stop("The following arguments are in 'tx_transform_args' but are",
            " not defined in 'tx_transform_fun': ",
-           paste0(names_args[!names_args %in% names_fun], collapse=","))
+           paste0(names_args[!names_args %in% names_fun], collapse=","),
+           call.=FALSE)
     }
   }
 
@@ -585,7 +618,7 @@ check_inputs_node_time_to_event <- function(data, parents, sim_time, name,
            inherits(formals(prob_fun)[[arg_names[i]]], "name")) {
           stop("All parameters of 'prob_fun' except 'data' and 'sim_time'",
                " must be included in the node_td() call if they don't have a",
-               " default value.")
+               " default value.", call.=FALSE)
         }
       }
     }
@@ -645,7 +678,7 @@ check_inputs_node_competing_events <- function(data, parents, sim_time, name,
                        names(prob_fun_args))) {
           stop("All parameters of 'prob_fun' except 'data' and 'sim_time'",
                " must be included in the node_td() call if they don't have a",
-               " default value.")
+               " default value.", call.=FALSE)
         }
       }
     }
@@ -659,18 +692,18 @@ check_inputs_sim_n_datasets <- function(dag, n_repeats, n_cores,
 
   if (!inherits(dag, "DAG")) {
     stop("'dag' must be a DAG object created using the empty_dag()",
-         " and node() or node_td() functions.")
+         " and node() or node_td() functions.", call.=FALSE)
   } else if (!(length(n_repeats)==1 && is.numeric(n_repeats) &&
                n_repeats >= 1)) {
-    stop("'n_repeats' must a single positive number.")
+    stop("'n_repeats' must a single positive number.", call.=FALSE)
   } else if (!(length(n_cores)==1 && is.numeric(n_cores) &&
                n_cores >= 1)) {
-    stop("'n_cores' must be a single positive number.")
+    stop("'n_cores' must be a single positive number.", call.=FALSE)
   } else if (!(length(data_format)==1 && is.character(data_format))) {
-    stop("'data_format' must be a single character string.")
+    stop("'data_format' must be a single character string.", call.=FALSE)
   } else if (!is.list(data_format_args)) {
-    stop("'data_format_args' must be a list.")
+    stop("'data_format_args' must be a list.", call.=FALSE)
   } else if (!(length(progressbar)==1 && is.logical(progressbar))) {
-    stop("'progressbar' must be either TRUE or FALSE.")
+    stop("'progressbar' must be either TRUE or FALSE.", call.=FALSE)
   }
 }
