@@ -38,3 +38,17 @@ test_that("using a formula", {
 
   expect_equal(mean(out$B), 9830064)
 })
+
+test_that("using a special formula", {
+
+  set.seed(23426)
+
+  dag <- empty_dag() +
+    node("A", type="rnorm", mean=12, sd=10) +
+    node("B", type="poisson", formula=~1 + A*0.2 + I(A^2)*0.01,
+         intercept=1)
+
+  out <- sim_from_dag(dag=dag, n_sim=100)
+
+  expect_equal(mean(out$B), 9830064)
+})
