@@ -21,7 +21,8 @@ test_that("overall test case 1 time_to_event node", {
 
   sim <- list(max_t=max_t,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=5)),
               data=data.table(.id=seq(1, n_sim),
                               A_event=FALSE,
@@ -69,13 +70,16 @@ test_that("overall test case 3 time_to_event nodes", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=5),
                             list(name="C",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=15)),
               data=data.table(.id=c(1, 2, 3),
                               A_event=FALSE,
@@ -111,10 +115,12 @@ test_that("two events stopping at the same time", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=5)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -142,10 +148,12 @@ test_that("two events starting at the same time", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=5)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -173,10 +181,12 @@ test_that("one event starting when other ends", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=6),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -203,10 +213,12 @@ test_that("one event starting one t before other ends", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=6),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -233,10 +245,12 @@ test_that("event starting right when the same event just ended", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=6),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -264,10 +278,12 @@ test_that("node containing no events", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=6),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -294,10 +310,12 @@ test_that("no events in any nodes", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=6),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -321,10 +339,12 @@ test_that("event at t = max_t", {
 
   sim <- list(max_t=11,
               tx_nodes=list(list(name="A",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=6),
                             list(name="B",
-                                 type="time_to_event",
+                                 type_str="time_to_event",
+                                 type_fun=node_time_to_event,
                                  event_duration=10)),
               data=data.table(.id=1,
                               A_event=FALSE,
@@ -370,7 +390,7 @@ test_that("no time-to-event nodes in data", {
 
   dag <- empty_dag() +
     node("age", type="rnorm", mean=20, sd=10) +
-    node_td("some_nonsense", type="gaussian", formula=~age,
+    node_td("some_nonsense", type="gaussian", parents="age",
             betas=0.1, intercept=-1, error=5)
 
   sim <- sim_discrete_time(dag=dag, n_sim=10, max_t=20)
